@@ -2,6 +2,6 @@ from .dataset import Dataset,load_image_files,IMG_EXTENSIONS
 from .network import load_model
 from .predict import Predictor,PredictConfigBase
 from .training import train,TrainValConfigBase,val
-from .testing import test,TestConfigBase
+from .testing import test,TestConfigBase,plot_result
 from .config import *
 from .transforms import *
\ No newline at end of file
