@@ -25,20 +25,41 @@ def test(cfg):
     predictor=cfg.get_predictor()
     outFolder=wk.Folder(cfg.TEST_OUTPUT_DIR)
     res={}
+    files={}
+    probs=[]
     print('Num images: %s'%(len(fs)))
     for i,f in enumerate(fs):
         img=cv2.imread(f)
         if img is None:
-            raise Exception('Failed to load %s'%(f))
+            print('Failed to load %s'%(f))
+            continue
         cls,prob=predictor.predict(img)
+        probs.append(predictor.cache['probs'])
 
         if cfg.SPLIT_BY_PROB:
             outFolder.openFolder(cls).openFolder('%.1f'%(prob)).eat(f)
         else:
             outFolder.openFolder(cls).eat(f)
         print(i,f,cls)
-        res[f]=[cls,prob]
+        files[f]=[cls,prob]
+
+    res['files']=files
+    res['probs']=probs
     return res
+def plot_result(res,cls=0,xlabel='',ylabel=''):
+    res=res['probs']
+    res=[res[i][cls] for i in range(len(res))]
+    res.sort()
+    xs = []
+    ys = []
+    for i in range(len(res)):
+        xs.append(res[i])
+        ys.append(i / len(res))
+    from matplotlib import pyplot as plt
+    plt.plot(xs,ys)
+    plt.xlabel(xlabel)
+    plt.ylabel(ylabel)
+    plt.show()
 
 if __name__ == '__main__':
     test(TestConfigBase())
\ No newline at end of file
