@@ -256,8 +256,8 @@ def train(cfg):
     assert isinstance(cfg, TrainValConfigBase)
     train_data = cfg.train_data
     model = cfg.model
-    optimizer = torch.optim.Adam(model.parameters(), lr=cfg.LR_INIT)
-    # optimizer = optim.SGD(model.parameters(), lr=cfg.LR_INIT, momentum=0.9)
+    # optimizer = torch.optim.Adam(model.parameters(), lr=cfg.LR_INIT)
+    optimizer = optim.SGD(model.parameters(), lr=cfg.LR_INIT, momentum=0.9)
     lr_scheduler = torch.optim.lr_scheduler.CosineAnnealingLR(optimizer, cfg.MAX_EPOCHS, cfg.LR_END)
 
     global_step = -1
