@@ -24,5 +24,5 @@ def decrypt_model(src,dst=None,key=0xef):
 if __name__ == '__main__':
     pass
     encrypt_model(
-        src='/home/ars/sda6/work/play/wk-classify/local/capacitor_color1_face2/model_best_[capacitor][0916][resnet18][face1][epoch=5&acc=0.9350].onnx'
+        src='/home/ars/sda6/work/play/wk-classify/local/capacitor_color1_face0/model_best_[capacitor][0918][resnet18][color1][face0][cropped][epoch=29&acc=0.9538].onnx'
     )
\ No newline at end of file
